Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(277)

Unified Diff: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/DeleteResourceParticipantTest.java

Issue 12340077: Initial binding of RenameRefactoring service to Eclipse. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 7 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/DeleteResourceParticipantTest.java
diff --git a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/DeleteResourceParticipantTest.java b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/DeleteResourceParticipantTest.java
index f0f4f6f6cb638f28c31ef3ddf41220c08c3d8866..86c07c73826c3ee704130005a1b71ca11935dbea 100644
--- a/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/DeleteResourceParticipantTest.java
+++ b/editor/tools/plugins/com.google.dart.tools.ui_test/src/com/google/dart/tools/ui/refactoring/DeleteResourceParticipantTest.java
@@ -18,7 +18,7 @@ import com.google.dart.tools.core.model.DartVariableDeclaration;
import com.google.dart.tools.internal.corext.refactoring.rename.DeleteResourceParticipant;
import com.google.dart.tools.internal.corext.refactoring.rename.RenameResourceParticipant;
import com.google.dart.tools.internal.corext.refactoring.util.ReflectionUtils;
-import com.google.dart.tools.ui.internal.refactoring.RenameSupport;
+import com.google.dart.tools.ui.internal.refactoring.RenameSupport_OLD;
import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IResource;
@@ -41,7 +41,7 @@ public final class DeleteResourceParticipantTest extends RefactoringTest {
}
/**
* Uses {@link RenameSupport} to rename {@link DartVariableDeclaration}.
*/
@SuppressWarnings("restriction")
private static void deleteFile(IFile file) throws Exception {

Powered by Google App Engine
@@ -41,7 +41,7 @@ public final class DeleteResourceParticipantTest extends RefactoringTest {
}
/**
- * Uses {@link RenameSupport} to rename {@link DartVariableDeclaration}.
+ * Uses {@link RenameSupport_OLD} to rename {@link DartVariableDeclaration}.
*/
This is Rietveld 408576698